@@ -48,8 +48,24 @@ def required_pkg_config_package(package_info, native_package_info=nil)
 end
 
 unless required_pkg_config_package([package, major, minor, micro],
+                                   :alt_linux => [
+                                     "bzlib-devel",
+                                     "libXdmcp-devel",
+                                     "libbrotli-devel",
+                                     "libcairo-devel",
+                                     "libexpat-devel",
+                                     "libpixman-devel",
+                                   ],
                                    :arch_linux => "cairo",
+                                   :conda => [
+                                     "cairo",
+                                     "xorg-libxau",
+                                     "xorg-libxext",
+                                     "xorg-libxrender",
+                                     "xorg-xproto",
+                                   ],
                                    :debian => "libcairo2-dev",
+                                   :gentoo_linux => "cairo",
                                    :homebrew => "cairo",
                                    :macports => "cairo",
                                    :msys2 => "cairo",
